summaryrefslogtreecommitdiff
path: root/src/jit/gentree.cpp
diff options
context:
space:
mode:
authorCarol Eidt <carol.eidt@microsoft.com>2019-06-18 13:12:31 -0700
committerGitHub <noreply@github.com>2019-06-18 13:12:31 -0700
commit3091448eae1af315ad78d9fc18ad1ee077afc795 (patch)
tree2700e8f29ee0eb092ce69991d9530bd9b4bdd055 /src/jit/gentree.cpp
parent0ad43be30fa7e611bef57c4b8e4fdd4a34bd65f4 (diff)
downloadcoreclr-3091448eae1af315ad78d9fc18ad1ee077afc795.tar.gz
coreclr-3091448eae1af315ad78d9fc18ad1ee077afc795.tar.bz2
coreclr-3091448eae1af315ad78d9fc18ad1ee077afc795.zip
Fix contained LEA handling (#25135)
* Fix contained LEA handling This adds an LEA case to both `LinearScan::BuildOperandUses` and `CodeGen::genConsumeRegs`. Fix #25039
Diffstat (limited to 'src/jit/gentree.cpp')
-rw-r--r--src/jit/gentree.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/jit/gentree.cpp b/src/jit/gentree.cpp
index 3a0629edaf..c635c327c5 100644
--- a/src/jit/gentree.cpp
+++ b/src/jit/gentree.cpp
@@ -11436,8 +11436,8 @@ void Compiler::gtDispLIRNode(GenTree* node, const char* prefixMsg /* = nullptr *
printf("%*s", (int)prefixIndent, "");
}
- // 49 spaces for alignment
- printf("%-49s", "");
+ // 50 spaces for alignment
+ printf("%-50s", "");
#if FEATURE_SET_FLAGS
// additional flag enlarges the flag field by one character
printf(" ");